aboutsummaryrefslogtreecommitdiffstats
path: root/src/command/login.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/command/login.rs')
-rw-r--r--src/command/login.rs14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/command/login.rs b/src/command/login.rs
index c33fa5e1..fe442bc1 100644
--- a/src/command/login.rs
+++ b/src/command/login.rs
@@ -2,23 +2,25 @@ use std::borrow::Cow;
use std::io;
use atuin_common::api::LoginRequest;
+use clap::AppSettings;
+use clap::Parser;
use eyre::Result;
-use structopt::StructOpt;
use tokio::{fs::File, io::AsyncWriteExt};
use atuin_client::api_client;
use atuin_client::settings::Settings;
-#[derive(StructOpt)]
-#[structopt(setting(structopt::clap::AppSettings::DeriveDisplayOrder))]
+#[derive(Parser)]
+#[clap(setting(AppSettings::DeriveDisplayOrder))]
pub struct Cmd {
- #[structopt(long, short)]
+ #[clap(long, short)]
pub username: Option<String>,
- #[structopt(long, short)]
+ #[clap(long, short)]
pub password: Option<String>,
#[structopt(long, short, help = "the encryption key for your account")]
pub key: Option<String>,
}
@@ -2,23 +2,25 @@ use std::borrow::Cow;
pub password: Option<String>,
- #[structopt(long, short, help = "the encryption key for your account")]
+ /// The encryption key for your account
+ #[clap(long, short)]
pub key: Option<String>,
}